
local tooltipScanner
local tooltipName = "BagArtifactPowerTooltipScanner"

local function AddToFrame(frame, func)
    if frame then
        frame.BagArtifactPowerText = frame:CreateFontString(nil, "OVERLAY", "GameFontNormalLarge")
        frame.BagArtifactPowerText:SetPoint("CENTER", 0, 0)
        if func then
            frame:HookScript("OnUpdate", func)
        end
    end
end

local function GetItemLinkArtifactPower(itemLink)
    if itemLink then
        local itemSpell = GetItemSpell(itemLink)
        if itemSpell and itemSpell == "Empowering" then
            tooltipScanner:SetOwner(UIParent, "ANCHOR_NONE")
            tooltipScanner:SetHyperlink (itemLink)
            local ap = _G[tooltipName.."TextLeft4"]:GetText():match("%d.-%s") or ""
            if ap then
                ap = tonumber(ap)
                if ap > 1000000 then
                    ap = (math.floor(ap / 10000 + 0.5) / 100) .. "M"
                elseif ap > 1000 then
                    ap = (math.floor(ap / 10 + 0.5) / 100) .. "K"
                else
                    ap = ap .. ""
                end
            end
            tooltipScanner:Hide()
            return ap
        else
            return nil
        end
    else
        return nil
    end

end

local function GetBagArtifactPower(bag, slot)
    local itemLink = GetContainerItemLink(bag, slot)
    return GetItemLinkArtifactPower(itemLink)
end

local function ContainerFrame_OnShow(frame, elapsed)
    local textFrame = frame.BagArtifactPowerText
    if textFrame then
        local bag, slot = frame:GetParent():GetID(), frame:GetID()
        local ap = GetBagArtifactPower(bag, slot)
        if ap then
            if ap ~= textFrame:GetText() then
                textFrame:SetText(ap)
            end
        else 
            if textFrame:GetText() then
                textFrame:SetText()
            end
        end
    end
end

local function Init()
    local i
    for i = 1, NUM_CONTAINER_FRAMES do
        for j = 1, MAX_CONTAINER_ITEMS do
            local frame = _G["ContainerFrame"..i.."Item"..j]
            AddToFrame(frame, ContainerFrame_OnShow)
        end
    end
    tooltipScanner = CreateFrame("GameTooltip", tooltipName, nil, "GameTooltipTemplate")
    
end

Init()